@@ -44,6 +44,7 @@ use nextest_runner::{
     target_runner::TargetRunner,
     test_filter::{BinaryFilter, TestFilterBuilder},
     test_output::CaptureStrategy,
+    user_config::{DefaultUserConfig, UserConfig},
     write_str::WriteStr,
 };
 use owo_colors::OwoColorize;
@@ -656,6 +657,10 @@ impl App {
             .color
             .should_colorize(supports_color::Stream::Stderr);
 
+        // Load user config for UI settings and get embedded defaults.
+        let user_config = UserConfig::from_default_location().map_err(Box::new)?;
+        let default_user_config = DefaultUserConfig::from_embedded();
+
         // Make the runner and reporter builders. Do them now so warnings are
         // emitted before we start doing the build.
         let runner_builder = runner_opts.to_builder(cap_strat);
@@ -663,6 +668,8 @@ impl App {
             runner_opts.no_run,
             no_capture || runner_opts.interceptor.is_active(),
             should_colorize,
+            user_config.as_ref().map(|c| &c.ui),
+            &default_user_config.ui,
         );
         reporter_builder.set_verbose(self.base.output.verbose);
 
@@ -746,12 +753,21 @@ impl App {
 
         let input_handler =
             if reporter_opts.no_input_handler || runner_opts.interceptor.debugger.is_some() {
-                // Only debuggers disable the input handler.
+                // Only debuggers disable the input handler -- tracers do not.
                 InputHandlerKind::Noop
             } else {
-                // This means that the input handler determines whether it
-                // should be enabled.
-                InputHandlerKind::Standard
+                // Check user config, falling back to embedded default.
+                let enabled = user_config
+                    .as_ref()
+                    .and_then(|c| c.ui.input_handler)
+                    .unwrap_or(default_user_config.ui.input_handler);
+                if enabled {
+                    // This means that the input handler determines whether it
+                    // should be enabled.
+                    InputHandlerKind::Standard
+                } else {
+                    InputHandlerKind::Noop
+                }
             };
 
         // Make the runner.
@@ -816,10 +832,18 @@ impl App {
             .color
             .should_colorize(supports_color::Stream::Stderr);
 
+        // Load user config for UI settings and get embedded defaults.
+        let user_config = UserConfig::from_default_location().map_err(Box::new)?;
+        let default_user_config = DefaultUserConfig::from_embedded();
+
         // Make the runner and reporter builders. Do them now so warnings are
         // emitted before we start doing the build.
         let runner_builder = runner_opts.to_builder(cap_strat);
-        let mut reporter_builder = reporter_opts.to_builder(should_colorize);
+        let mut reporter_builder = reporter_opts.to_builder(
+            should_colorize,
+            user_config.as_ref().map(|c| &c.ui),
+            &default_user_config.ui,
+        );
         reporter_builder.set_verbose(self.base.output.verbose);
 
         let filter_exprs =
@@ -902,12 +926,19 @@ impl App {
 
         let input_handler =
             if reporter_opts.no_input_handler || runner_opts.interceptor.debugger.is_some() {
-                // Only debuggers disable the input handler.
+                // Only debuggers disable the input handler -- tracers do not.
                 InputHandlerKind::Noop
             } else {
-                // This means that the input handler determines whether it
-                // should be enabled.
-                InputHandlerKind::Standard
+                // Check user config, falling back to embedded default.
+                let enabled = user_config
+                    .as_ref()
+                    .and_then(|c| c.ui.input_handler)
+                    .unwrap_or(default_user_config.ui.input_handler);
+                if enabled {
+                    InputHandlerKind::Standard
+                } else {
+                    InputHandlerKind::Noop
+                }
             };
 
         // Make the runner.
